"""
    A container for pyChapel name and version.
"""
APP_NAME = 'pyChapel'
APP_VERSION = '0.1.11'
